/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014, 2015, 2016
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef TEMPERHUMDATASOURCE_H
#define TEMPERHUMDATASOURCE_H

#include "abstractdatasource.h"

#include <hidapi.h>
#include <QTimer>
#include <QScopedPointer>

typedef struct _th_reading_t {
    float temperature;
    float humidity;
} temp_hum_reading_t;

class TemperHumDataSource : public AbstractDataSource
{
    Q_OBJECT
public:
    TemperHumDataSource(float temperatureCalibrationOffset = 0.0,
                        float humidityCalibrationOffset = 0.0,
                        QObject *parent = 0);
    ~TemperHumDataSource();

    virtual bool openDevice();
    virtual bool closeDevice();

    void setInterval(int interval);
    int getInterval() const;

    virtual void startCollecting();
    virtual void stopCollecting();
    virtual bool isCollecting();

protected slots:
    virtual void collectData();

private:
    hid_device *handle;
    QScopedPointer<QTimer> timer;

    temp_hum_reading_t getCalibrationValue() const;
    QString getVersion() const;
    temp_hum_reading_t getReading() const;
    float temperatureCalibrationOffset;
    float humidityCalibrationOffset;
    bool collecting;
};

#endif // TEMPERHUMDATASOURCE_H
