 #----------------------------------------------------------------------------
 #          Copyright: (C) Copyright David Goodwin, 2014
 #            License: GNU General Public License
 #----------------------------------------------------------------------------
 #
 #   This is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This software is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
 #   along with this software; if not, write to the Free Software
 #   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #
 #----------------------------------------------------------------------------

QT       += core gui sql

greaterThan(QT_MAJOR_VERSION, 4): QT += widgets printsupport

TARGET = tempview
TEMPLATE = app

# Turn on C++11 support
CONFIG += c++11

# HID API for Windows - use precompiled binaries
win32 {
    LIBS += -L$${PWD}/lib/hidapi/windows-binaries -lhidapi
    INCLUDEPATH += lib/hidapi/windows-binaries
}

# HID API for Linux - compile into app.
unix {
    SOURCES += lib/hidapi/linux-0.7/hid-libusb.c
    INCLUDEPATH += lib/hidapi/linux-0.7/

    # Edit this stuff for libusb-1.0. Defaults should
    # be ok for debian-based distros.
    LIBS += -lusb-1.0
    INCLUDEPATH += /usr/include/libusb-1.0
}

SOURCES += main.cpp\
        mainwindow.cpp \
    abstractdatasource.cpp \
    temperdatasource.cpp \
    qcp/qcustomplot.cpp \
    aboutdialog.cpp \
    databasedatasource.cpp \
    settings.cpp \
    dbutil.cpp \
    settingsdialog.cpp \
    qtcolorbutton/qtcolorbutton.cpp \
    abstractdatalogger.cpp \
    postgresqldatalogger.cpp \
    sqlitedatalogger.cpp \
    chartoptionsdialog.cpp \
    chartwindow.cpp \
    basicqcpinteractionmanager.cpp \
    exportdialog.cpp \
    temperhumdatasource.cpp

HEADERS  += mainwindow.h \
    abstractdatasource.h \
    temperdatasource.h \
    qcp/qcustomplot.h \
    aboutdialog.h \
    defs.h \
    constants.h \
    databasedatasource.h \
    settings.h \
    dbutil.h \
    settingsdialog.h \
    qtcolorbutton/qtcolorbutton.h \
    qtcolorbutton/qtcolorbutton_p.h \
    abstractdatalogger.h \
    postgresqldatalogger.h \
    sqlitedatalogger.h \
    chartoptionsdialog.h \
    chartwindow.h \
    samplecolumns.h \
    basicqcpinteractionmanager.h \
    sampleset.h \
    exportdialog.h \
    temperhumdatasource.h

FORMS    += mainwindow.ui \
    aboutdialog.ui \
    settingsdialog.ui \
    chartoptionsdialog.ui \
    chartwindow.ui \
    exportdialog.ui

#
# To translate to a new language:
#   1. Add a new translation file below (eg, tempview_fr.ts for French)
#   2. To generate the .ts files, from a console run: lupdate tempview.pro
#   3. Open the .ts file in Qt Linguist and translate the strings
#   4. To generate the .qm translation files used by TempView at runtime,
#      run the following from a console: lrelease tempview.pro
#
TRANSLATIONS = tempview_en.ts

RESOURCES += \
    resources.qrc

RC_FILE = tempview.rc

OTHER_FILES = tempview.rc db/sqlite-schema.sql db/postgres-schema.sql
OTHER_FILES += db/postgres-schema-upgrade.sql db/sqlite-schema-upgrade.sql

# Magic distribution archive building crap
#  On Windows (and, in theory, Mac) it will find all the DLLs we depend on and
#  copy them into the right place.
#
#  It also pulls in a load of other stuff this application doesn't actually
#  need so it will probably want trimming a little (eg, most of the sql drivers)

isEmpty(TARGET_EXT) {
    win32 {
        TARGET_CUSTOM_EXT = .exe
    }
    macx {
        TARGET_CUSTOM_EXT = .app
    }
} else {
    TARGET_CUSTOM_EXT = $${TARGET_EXT}
}

win32 {
    DEPLOY_COMMAND = windeployqt
}
macx {
    DEPLOY_COMMAND = macdeployqt
}

CONFIG( debug, debug|release ) {
    # debug
    DEPLOY_TARGET = $$shell_quote($$shell_path($${OUT_PWD}/debug/$${TARGET}$${TARGET_CUSTOM_EXT}))
} else {
    # release
    DEPLOY_TARGET = $$shell_quote($$shell_path($${OUT_PWD}/release/$${TARGET}$${TARGET_CUSTOM_EXT}))
}

#  # Uncomment the following line to help debug the deploy command when running qmake
# warning($${DEPLOY_COMMAND} $${DEPLOY_TARGET})

# Use += instead of = if you use multiple QMAKE_POST_LINKs
QMAKE_POST_LINK = $${DEPLOY_COMMAND} $${DEPLOY_TARGET}
